package Bundle::Compress::Zlib;

use strict;
use warnings;

our $VERSION = '0.01';



1;
__END__


=head1 NAME

Bundle::Compress::Zlib - installs Zlib modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Compress::Zlib'

=head1 CONTENTS

XSLoader

List::Util

Text::Unidecode

Text::Wrap

Scalar::Util

Getopt::Long

Pod::Escapes

Pod::Man

Pod::Usage

File::Spec

Test::Harness

Test::Simple

Test::More

Error

Cwd

Devel::Symdump

Class::Inner

File::Slurp

File::Find::Rule

Config::Tiny

Params::Util

Class::Autouse

Algorithm::Dependency

File::Flat

Test::ClassAPI

Class::Inspector

Pod::Tests

IO

IO::Handle

Test::Inline

IO::Compress::Base

IO::Compress::Base::Common

IO::Uncompress::Base

IO::Compress::Gzip

IO::Compress::Gzip::Constants

IO::Uncompress::Gunzip

Compress::Raw::Zlib

Compress::Zlib

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
